<?php

namespace Opencart\System\Library\Extension\Chatbro\Chatbroapp\Backends;

use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Interfaces\IcbroUtilsBackend;
use Opencart\System\Library\Extension\Chatbro\Chatbroapp\Api\CbroApi;

class CbroUtilsBackend implements IcbroUtilsBackend
{
  static private $scripts_count = 0;
  static private $styles_count = 0;
  private $cms;

  public function __construct($cms)
  {
    $this->cms = $cms;
    $this->cms->load->language('extension/chatbro/module/chatbro');
  }

  function get_site_url()
  {
    return $this->cms->chatbroapp->getStoreUrl();
  }

  function generated_scripts() 
  {
    $get_chats = html_entity_decode($this->cms->model_extension_chatbro_proxy_url->link('extension/chatbro/module/chatbro|get_chats', 'store_id=' . $this->cms->store_id . '&user_token=' . $this->cms->session->data['user_token'], true), ENT_QUOTES, 'UTF-8');
    $create_chat = html_entity_decode($this->cms->model_extension_chatbro_proxy_url->link('extension/chatbro/module/chatbro|create_chat', 'store_id=' . $this->cms->store_id . '&user_token=' . $this->cms->session->data['user_token'], true), ENT_QUOTES, 'UTF-8');
    $delete_chat = html_entity_decode($this->cms->model_extension_chatbro_proxy_url->link('extension/chatbro/module/chatbro|delete_chat', 'store_id=' . $this->cms->store_id . '&user_token=' . $this->cms->session->data['user_token'], true), ENT_QUOTES, 'UTF-8');
    $update_chat = html_entity_decode($this->cms->model_extension_chatbro_proxy_url->link('extension/chatbro/module/chatbro|update_chat', 'store_id=' . $this->cms->store_id . '&user_token=' . $this->cms->session->data['user_token'], true), ENT_QUOTES, 'UTF-8');
    $save_settings = html_entity_decode($this->cms->model_extension_chatbro_proxy_url->link('extension/chatbro/module/chatbro|save_settings', 'store_id=' . $this->cms->store_id . '&user_token=' . $this->cms->session->data['user_token'], true), ENT_QUOTES, 'UTF-8');

    ?>
    <script>
      var cBroGlobals = {
        saveSettingsUrl: "<?php echo($save_settings); ?>",
        createChatUrl: "<?php echo($create_chat); ?>",
        deleteChatUrl: "<?php echo($delete_chat); ?>",
        updateChatUrl: "<?php echo($update_chat); ?>",
        getChatsUrl: "<?php echo($get_chats); ?>",
        getFaqUrl: "/faq/get",
        cms: "<?php echo(CbroApi::get_platform_name()); ?>",
        chatShortcodeTemplate: '{{ chatbro.render({ "id": "%s", "static": true }) }}',
        childShortcodeTemplate: '{{ chatbro.render({ "id": "%s", "child": true, "title": "Child chat %s", "static": true }) }}',
        dropDownConflict: false
      };
    </script>
    <?php
  }

  function get_site_domain()
  {
    $url = self::get_site_url();
    if (!preg_match('/^.+:\/\/([^\/\:]+)/', $url, $m))
      return '';

    return $m[1];
  }

  function get_platform()
  {
    return 'opencart-plugin-' . 1 . '.' . 2;
  }

  function is_front_page()
  {
    $route = $this->cms->request->get['route'] ?? null;
    return is_null($route) || ("common/home" === $route);

    // echo(json_encode($this->cms->request));
    // echo($this->cms->url->link($this->cms->request->get['route']) ?? null);
    // echo($this->cms->request->get['route'] ?? null);

    // $server = $this->cms->chatbroapp->getStoreUrl();
		// $host_and_uri = parse_url($server, PHP_URL_HOST) . parse_url($server, PHP_URL_PATH);


    // $server = $this->googleshopping->getStoreUrl();

    // $host_and_uri = parse_url($server, PHP_URL_HOST) . parse_url($server, PHP_URL_PATH);

    // return is_front_page();

  }

  function match_path($path, $patterns)
  {
    $to_replace = array(
      '/(\r\n?|\n)/',
      '/\\\\\*/',
    );
    $replacements = array(
      '|',
      '.*',
    );
    $patterns_quoted = preg_quote($patterns, '/');
    $regexps = '/^(' . preg_replace($to_replace, $replacements, $patterns_quoted) . ')$/';
    return (bool) preg_match($regexps, $path);
  }


  function check_path($display, $selected_pages) {
    $route = $this->cms->request->get['route'] ?? null;

    if (is_null($route)) {
      $route = "common/home";
    }

    $page_match = false;
    $selected_pages = trim($selected_pages);

    if ($selected_pages != '') {

      if (function_exists('mb_strtolower')) {
        $pages = mb_strtolower($selected_pages);
        $path = mb_strtolower($route);
      } else {
        $pages = strtolower($selected_pages);
        $path = strtolower($route);
      }

      $page_match = self::match_path($path, $pages);

      if ($display == 'except_listed')
        $page_match = !$page_match;
    }

    return $page_match;
  }


  // route=product/category&language=en-gb&path=25_28

  function enque_script()
  {
  }

  function enque_style()
  {
  }

  function translate($text) {
    
    // $this->document->setTitle($this->language->get('heading_title'));
    return $this->cms->language->get($text);
  }

  function get_locale()
  {
    return $this->cms->language->get('code');
  }

  function get_request_var($var_name)
  {
    return array_key_exists($var_name, $this->cms->request->post) ? $this->cms->request->post[$var_name] : null;
  }

  function get_home_url()
  {
    return $this->cms->chatbroapp->getStoreUrl();
  }

  function get_default_profile_url()
  {
    return $this->cms->chatbroapp->getStoreUrl();
  }

  /*
  Возвращает значение атрибута data-offset-top (кол-во пикселей отступа от верха
  экрана, доехав до которого чат перестает скроллироваться) для чата поддержки.
  */
  function get_support_chat_data_offset_top()
  {
    return 53;
  }


}

?>